# inspired from:

# https://python-packaging-user-guide.readthedocs.org/en/latest/single_source_version/
# https://github.com/pypa/warehouse/blob/master/warehouse/__about__.py

__title__ = 'cymem'
__version__ = '1.31.2'
__summary__ = 'Manage calls to calloc/free through Cython'
__uri__ = 'https://github.com/spacy-io/cymem'
__author__ = 'Matthew Honnibal'
__email__ = 'matt@spacy.io'
__license__ = 'MIT'
